@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  * Copyright (C) 2012 Intel Corporation
@@ -28,6 +27,7 @@
 
 #include <sys/types.h>
 #include <gio/gio.h>
+#include <libsoup/soup.h>
 
 #include <libedataserver/e-source-enums.h>
 
@@ -64,6 +64,8 @@ gchar *		e_util_utf8_data_make_valid	(const gchar *data,
 gchar *         e_util_utf8_normalize           (const gchar *str);
 const gchar *   e_util_ensure_gdbus_string	(const gchar *str,
 						 gchar **gdbus_str);
+gboolean	e_util_host_is_in_domain	(const gchar *host,
+						 const gchar *domain);
 guint64		e_util_gthread_id		(GThread *thread);
 void		e_filename_make_safe		(gchar *string);
 gchar *		e_filename_mkdir_encoded	(const gchar *basepath,
@@ -163,48 +165,6 @@ gchar *		e_util_replace_prefix		(const gchar *configure_time_prefix,
 void		e_util_win32_initialize		(void);
 #endif
 
-/* utility functions for easier processing of named parameters */
-
-/**
- * ENamedParameters:
- *
- * Since: 3.8
- **/
-struct _ENamedParameters;
-typedef struct _ENamedParameters ENamedParameters;
-
-#define E_TYPE_NAMED_PARAMETERS (e_named_parameters_get_type ())
-
-GType           e_named_parameters_get_type     (void) G_GNUC_CONST;
-ENamedParameters *
-		e_named_parameters_new		(void);
-ENamedParameters *
-		e_named_parameters_new_strv	(const gchar * const *strv);
-ENamedParameters *
-		e_named_parameters_new_string	(const gchar *str);
-ENamedParameters *
-		e_named_parameters_new_clone	(const ENamedParameters *parameters);
-void		e_named_parameters_free		(ENamedParameters *parameters);
-void		e_named_parameters_clear	(ENamedParameters *parameters);
-void		e_named_parameters_assign	(ENamedParameters *parameters,
-						 const ENamedParameters *from);
-void		e_named_parameters_set		(ENamedParameters *parameters,
-						 const gchar *name,
-						 const gchar *value);
-const gchar *	e_named_parameters_get		(const ENamedParameters *parameters,
-						 const gchar *name);
-gchar **	e_named_parameters_to_strv	(const ENamedParameters *parameters);
-gchar *		e_named_parameters_to_string	(const ENamedParameters *parameters);
-gboolean	e_named_parameters_test		(const ENamedParameters *parameters,
-						 const gchar *name,
-						 const gchar *value,
-						 gboolean case_sensitively);
-gboolean	e_named_parameters_exists	(const ENamedParameters *parameters,
-						 const gchar *name);
-guint		e_named_parameters_count	(const ENamedParameters *parameters);
-gchar *		e_named_parameters_get_name	(const ENamedParameters *parameters,
-						 gint index);
-
 #define e_named_timeout_add(interval, function, data) \
 	(e_timeout_add_with_name ( \
 		G_PRIORITY_DEFAULT, (interval), \
@@ -298,6 +258,13 @@ gint		e_util_source_compare_for_sort	(struct _ESource *source_a,
 GPtrArray *	e_util_get_directory_variants	(const gchar *main_path,
 						 const gchar *replace_prefix,
 						 gboolean with_modules_dir);
+void		e_util_change_uri_component	(GUri **inout_uri,
+						 SoupURIComponent component,
+						 const gchar *value);
+void		e_util_change_uri_port		(GUri **inout_uri,
+						 gint port);
+void		e_util_call_malloc_trim		(void);
+gboolean	e_util_guess_source_is_readonly	(struct _ESource *source);
 
 G_END_DECLS
 
